# Changelog

## [2.3.1a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.3.1a1) (2024-11-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.3.0...2.3.1a1)

**Merged pull requests:**

- gl/translate [\#279](https://github.com/OpenVoiceOS/OVOS-workshop/pull/279) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
